body {
    font-family: 'Inter', sans-serif;
    margin: 0;
}

nav {
    height: 50px;
    display: flex;
    align-items: center;
    justify-content: space-between;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

a {
    color: inherit;
    text-decoration: none;
}

#nav-left {
    margin-left: 3rem;
    font-size: 110%;
}

#nav-right {
    margin-right: 1.5rem;
    display: flex;
}

#nav-right>a {
    color: #424242;
    margin-right: 1.5rem;
}

input[type=text],
input[type=submit],
button {
    background-color: white;
    padding: 0.5rem;
    border-radius: 0.5rem;
    border: 1px solid rgba(0, 0, 0, 0.12);
}

#error {
    max-width: 12.5rem;
    background-color: rgb(193, 55, 55);
    color: white;
    border-radius: 0.5rem;
    padding: 0.5rem;
    font-size: 0.8rem;
    position: fixed;
    bottom: 0.5rem;
    right: 0.5rem;
}

.hero {
    margin-top: 10vh;
    font-size: 2.75rem;
    text-align: center;
}

#content {
    margin-left: 10vw;
    width: 80vw;
}

@media (prefers-color-scheme: dark) {
    body {
        background-color: rgb(21, 20, 22);
        color: rgb(238, 238, 238);
    }

    nav {
        border-bottom: none;
    }

    input[type=text],
    input[type=submit],
    button {
        background-color: transparent;
        border: 1px solid rgba(255, 255, 255, 0.12);
    }

    input[type=text],
    input[type=submit],
    button,
    #nav-right>a {
        color: rgb(181, 181, 181);
    }
}